[Zope3-checkins] CVS: Zope3/src/persistence - dict.py:1.3

Steve Alexander steve@cat-box.net
Sun, 26 Jan 2003 07:02:50 -0500


Update of /cvs-repository/Zope3/src/persistence
In directory cvs.zope.org:/tmp/cvs-serv28952/src/persistence

Modified Files:
	dict.py 
Log Message:
Made PersistentDict derive from IterableUserDict instead of just
UserDict.


=== Zope3/src/persistence/dict.py 1.2 => 1.3 ===
--- Zope3/src/persistence/dict.py:1.2	Wed Dec 25 09:12:13 2002
+++ Zope3/src/persistence/dict.py	Sun Jan 26 07:02:46 2003
@@ -17,11 +17,11 @@
 """
 
 import persistence
-from UserDict import UserDict
+from UserDict import IterableUserDict
 
 __metaclass__ = type
 
-class PersistentDict(persistence.Persistent, UserDict):
+class PersistentDict(persistence.Persistent, IterableUserDict):
     """A persistent wrapper for mapping objects.
 
     This class allows wrapping of mapping objects so that object
@@ -29,20 +29,20 @@
     subclassed.
     """
 
     # UserDict provides all of the mapping behavior.  The
     # PersistentDict class is responsible marking the persistent
     # state as changed when a method actually changes the state.  At
     # the mapping API evolves, we may need to add more methods here.
 
-    __super_delitem = UserDict.__delitem__
-    __super_setitem = UserDict.__setitem__
-    __super_clear = UserDict.clear
-    __super_update = UserDict.update
-    __super_setdefault = UserDict.setdefault
-    __super_popitem = UserDict.popitem
+    __super_delitem = IterableUserDict.__delitem__
+    __super_setitem = IterableUserDict.__setitem__
+    __super_clear = IterableUserDict.clear
+    __super_update = IterableUserDict.update
+    __super_setdefault = IterableUserDict.setdefault
+    __super_popitem = IterableUserDict.popitem
 
     __super_p_init = persistence.Persistent.__init__
-    __super_init = UserDict.__init__
+    __super_init = IterableUserDict.__init__
 
     def __init__(self, dict=None):
         self.__super_init(dict)
@@ -29,20 +29,20 @@
     """
 
-    # UserDict provides all of the mapping behavior.  The
+    # IterableUserDict provides all of the mapping behavior.  The
     # PersistentDict class is responsible marking the persistent
     # state as changed when a method actually changes the state.  At